@@ -9,6 +9,7 @@ use std::fmt;
 use std::io::Error as IOError;
 use std::result::Result;
 use std::string::FromUtf8Error;
+use std::time::SystemTimeError;
 use struct_map::StructMapError;
 use ureq::Error as UreqError;
 
@@ -80,5 +81,10 @@ impl From<StructMapError> for AlipayError {
         AlipayError::new(error.to_string())
     }
 }
+impl From<SystemTimeError> for AlipayError {
+    fn from(error: SystemTimeError) -> Self {
+        AlipayError::new(error.to_string())
+    }
+}
 
 pub type AlipayResult<T> = Result<T, AlipayError>;
